@@ -122,18 +122,31 @@ def x_grouping(x_ls, y_ls, min_bin_ratio, missing_values):
 		raise Exception("[error] invalid x_type.")
 	return group_ls, x_type
 
+# x軸のmissingをxy系列から除去
+def del_missing_from_xy(org_x, org_y):
+	show_x, show_y = [], []
+	for x, y in zip(org_x, org_y):
+		if x == "missing": continue
+		show_x.append(x)
+		show_y.append(y)
+	return show_x, show_y
+
 # matplotlibで可視化 [quantile_scatter]
 def visualize(arg_data, x_type):
 	from matplotlib import pyplot as plt
 	for one_data in arg_data:
+		show_x, show_y = one_data["x"], one_data["y"]
+		if x_type == "number": show_x, show_y = del_missing_from_xy(one_data["x"], one_data["y"])	# x軸のmissingをxy系列から除去
 		# 描画
 		plt.plot(
-			one_data["x"], one_data["y"],
+			show_x, show_y,
 			label = one_data["label"],
 			marker = ".", markersize = 8
 		)
 	# 描画処理
 	plt.legend()
+	if show_x != one_data["x"]:	# x_typeがnumberでかつmissingが除去されている場合
+		plt.title("missing value is not plotted")	# タイトルとして警告文を挿入
 	if x_type == "nominal":
 		plt.xticks(rotation=90)
 		plt.tight_layout()
